@@ -100,6 +100,7 @@ def _get_user_settings(settings_dir, schema_name, schema):
         except ValidationError as e:
             warning = validation_warning % (schema_name, str(e))
             raw = '{}'
+            settings = {}
 
     return dict(
         raw=raw,
@@ -220,7 +221,7 @@ def _override(schema_name, schema, overrides):
                 new_defaults = schema['properties'][key]['default']
                 # If values for defaults are dicts do a recursive update
                 if isinstance(new_defaults, dict):
-                    recursive_update(new_defaults.copy(), defaults[key])
+                    recursive_update(new_defaults, defaults[key])
                 else:
                     new_defaults = defaults[key]
 
